@@ -18,7 +18,5 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from guiscrcpy.launcher import bootstrap
-
-print("Running guiscrcpy as a python module")
-bootstrap()
+from guiscrcpy.cli import cli
+cli()
